@@ -9,8 +9,10 @@
 #' @description Currency fluctuation data is only available for
 #' "Professional Plus" and "Enterprise" accounts.
 #'
-#' @param start_date The start date of requested time period.
-#' @param end_date The end date of requested time period.
+#' @param start_date The start date of requested time series, in "YYYY-MM-DD"
+#' style, or any style convertable to  "YYYY-MM-DD" using \code{as.Date()}.
+#' @param end_date The end date of requested time series, in "YYYY-MM-DD"
+#' style, or any style convertable to  "YYYY-MM-DD" using \code{as.Date()}.
 #' @inheritParams fixer_latest
 #' @seealso fixer_time_series
 #'
@@ -23,14 +25,14 @@
 #' @examples \dontrun{
 #'
 #' x <- fixer_fluctuation(start_date = "2018-02-25", end_date = "2018-02-26",
-#' symbols = c("USD", "JPY"))
+#'                        symbols = c("USD", "JPY"))
 #'
 #' }
 
 
 fixer_fluctuation <- function(start_date, end_date,
                               base = "EUR", symbols = NULL) {
-  date_check(start_date, end_date)
+  date_query <- date_check(start_date, end_date)
 
   base_query <- paste0("&base=", base)
 
